@@ -2,7 +2,7 @@
 # Check that nearest stations functions properly -------------------------------
 context("nearest_stations")
 
-test_that("nearest stations returns character value station IDs", {
+test_that("nearest stations returns station IDs nearest to farthest", {
   n <-
     nearest_stations(LAT = -27.5598,
                      LON = 151.9507,
@@ -12,15 +12,15 @@ test_that("nearest stations returns character value station IDs", {
   expect_equal(
     n,
     c(
-      "749459-99999",
-      "945420-99999",
       "945510-99999",
-      "945520-99999",
-      "945550-99999",
-      "945620-99999",
-      "945951-99999",
       "955510-99999",
-      "955550-99999"
+      "945520-99999",
+      "945620-99999",
+      "749459-99999",
+      "945550-99999",
+      "955550-99999",
+      "945951-99999",
+      "945420-99999"
     )
   )
   rm(n)
